import 'dart:io';

import 'package:transmedika_one_to_one_call/webrtc/socket_usecase_service.dart';
import 'package:transmedika_one_to_one_call/webrtc/websocket.dart'
if (dart.library.html) 'package:transmedika_one_to_one_call/webrtc/websocket_web.dart';
import 'package:transmedika_one_to_one_call/webrtc/websocket_service.dart';

/// Implement Use Case Web Socket ///
class SocketUseCase implements SocketUseCaseService{

  ///service web socket
  late WebSocketService socket;

  /// Connect to Web Socket ///
  @override
  Future<void> connect({
    required String url,
    required Function()? onOpen,
    required Function(dynamic)? onMessage,
    required Function(int? code, String? reason)? onClose}) async {
    try{
      socket = SimpleWebSocket(url);
      socket.onOpen = () {
        onOpen?.call();
      };

      /// on receive message from web socket///
      socket.onMessage = (message) {
        onMessage?.call(message);
      };

      /// on web socket close ///
      socket.onClose = (int? code, String? reason) {
        onClose?.call(code, reason);
      };

      await socket.connect();
    }on SocketException catch(e){
      onClose?.call(e.osError?.errorCode, e.osError?.message);
    }
  }

  /// Get Socket Instance ///
  @override
  WebSocketService getSocket() {
    return socket;
  }

  /// Close Web Socket ///
  @override
  Future<void> close() async {
    socket.close();
  }

}