import 'dart:io' if (dart.library.html) 'dart:html';

import 'package:flutter/foundation.dart';
import 'package:transmedika_one_to_one_call/webrtc/websocket_service.dart';

/// implement web socket class for mobile///
class SimpleWebSocket implements WebSocketService {
  final String _url;
  late WebSocket _socket;
  @override
  Function()? onOpen;
  @override
  Function(dynamic msg)? onMessage;
  @override
  Function(int code, String reason)? onClose;

  SimpleWebSocket(this._url);

  /// connect to web socket ///
  @override
  Future<void> connect() async {
    _socket = await WebSocket.connect(_url);
    onOpen?.call();
    _socket.listen((e) {
      onMessage?.call(e);
    }, onDone: () {
      onClose?.call(_socket.closeCode!, (_socket.closeReason?.isEmpty == true ? "Socket was close":_socket.closeReason!));
    }, onError: (e){
      onClose?.call(500, e.toString());
    });
  }

  /// send data to web socket ///
  @override
  send(data) async {
    try{
      _socket.add(data);
    }on Exception catch (e){
      if (kDebugMode) {
        print(e);
      }
    }
  }

  /// close web socket ///
  @override
  close() async {
    try{
      await _socket.close();
    }on Exception catch (e) {
      if (kDebugMode) {
        print(e);
      }
    }
  }
}